run

Function run 

pub async fn run(
    module_init_registry: ServerModuleInitRegistry,
    code_version_hash: &str,
    code_version_vendor_suffix: Option<&str>,
) -> Result<Infallible>
Block the thread and run a Fedimintd server

Arguments

  • module_init_registry - The registry of available modules.

  • code_version_hash - The git hash of the code that the fedimintd binary is being built from. This is used mostly for information purposes (fedimintd version-hash). See fedimint-build crate for easy way to obtain it.

  • code_version_vendor_suffix - An optional vendor string appended to the internal Fedimint release version, to distinguish binaries built by different vendors, usually with a different set of modules. It is encoded as SemVer build metadata and therefore must contain dot-separated, non-empty identifiers with only ASCII alphanumeric characters and hyphens. Setup/DKG compatibility and consensus config generation require the same exact optional vendor string as well as the same major.minor series.